# Image functions

## Initialization

```{eval-rst}
.. autoapisummary::

    deepali.core.image.circle_image
    deepali.core.image.cshape_image
    deepali.core.image.empty_image
    deepali.core.image.grid_image
    deepali.core.image.ones_image
    deepali.core.image.zeros_image

```

## Convolution

```{eval-rst}
.. autoapisummary::

    deepali.core.image.conv
    deepali.core.image.conv1d
```

## Pooling

```{eval-rst}
.. autoapisummary::

    deepali.core.image.avg_pool
    deepali.core.image.max_pool
    deepali.core.image.min_pool

```

## Resizing

```{eval-rst}
.. autoapisummary::

    deepali.core.image.gaussian_pyramid
    deepali.core.image.downsample
    deepali.core.image.upsample
    deepali.core.image.crop
    deepali.core.image.pad
    deepali.core.image.center_crop
    deepali.core.image.center_pad
    deepali.core.image.image_slice
    deepali.core.image.region_of_interest

```

## Rescaling

```{eval-rst}
.. autoapisummary::
    
    deepali.core.image.normalize_image
    deepali.core.image.rescale

```

## Derivatives

```{eval-rst}
.. autoapisummary::

    deepali.core.image.spatial_derivatives
    deepali.core.image.finite_differences

```

## Sampling

```{eval-rst}
.. autoapisummary::

    deepali.core.image.grid_resample
    deepali.core.image.grid_reshape
    deepali.core.image.grid_resize
    deepali.core.image.grid_sample
    deepali.core.image.grid_sample_mask
    deepali.core.image.sample_image
    deepali.core.image.rand_sample

```

## Miscellaneous

```{eval-rst}
.. autoapisummary::

    deepali.core.image.dot_batch
    deepali.core.image.dot_channels
    deepali.core.image.fill_border
    deepali.core.image.flatten_channels

```
